@@ -1,4 +1,4 @@
-# $Id: Cart.pm 380 2005-03-10 02:59:51Z claco $
+# $Id: Cart.pm 777 2005-09-09 02:01:23Z claco $
 package Handel::Cart;
 use strict;
 use warnings;
@@ -53,7 +53,12 @@ sub add {
 
         return $self->add_to__items($data);
     } else {
-        my %copy = %{$data};
+        my %copy;
+
+        foreach ($data->columns) {
+            next if $_ =~ /^(id|cart)$/i;
+            $copy{$_} = $data->$_;
+        };
 
         $copy{'id'} = $self->uuid;
 
@@ -88,6 +93,26 @@ sub delete {
         cart => $self->id)->delete_all;
 };
 
+sub destroy {
+    my ($self, $filter) = @_;
+
+    if (ref $self) {
+        $self->SUPER::delete;
+    } else {
+        throw Handel::Exception::Argument( -details =>
+            translate('Param 1 is not a HASH reference') . '.') unless
+                ref($filter) eq 'HASH';
+
+        my $carts = Handel::Cart->load($filter, RETURNAS_ITERATOR);
+        while (my $cart = $carts->next) {
+            $cart->clear;
+            $cart->SUPER::delete;
+        };
+    };
+
+    return;
+};
+
 sub items {
     my ($self, $filter, $wantiterator) = @_;
 
@@ -264,8 +289,7 @@ Handel::Cart - Module for maintaining shopping cart contents
 =head1 DESCRIPTION
 
 C<Handel::Cart> is quick and dirty component for maintaining simple shopping
-cart
-data.
+cart data.
 
 While C<Handel::Cart> subclasses L<Class::DBI>, it is strongly recommended that
 you not use its methods unless it's absolutely necessary. Stick to the
@@ -324,7 +348,7 @@ required name/values or by passing in a newly create Handel::Cart::Item
 object. If successful, C<add> will return a L<Handel::Cart::Item> object
 reference.
 
-Yes, I know. Why a hashref and not just a hash? So I can adding new parms
+Yes, I know. Why a hashref and not just a hash? So I can add new params
 later if need be. Oh yeah, and "Because I Can". :-P
 
 =over
@@ -366,7 +390,7 @@ containing all items.
 
     my $iterator = $cart->items;
     while (my $item = $iterator->next) {
-        print $cart->sku;
+        print $item->sku;
     };
 
     my @items = $cart->items;
@@ -424,6 +448,23 @@ returns the number of items deleted.
 
 =back
 
+=head2 Removing the Entire Cart
+
+=over
+
+=item C<$cart-E<gt>destroy(\%filter)>
+
+=item C<Handel::Cart-E<gt>destroy(\%filter)>
+
+When called used as an instance method, this will delete all items from the
+current cart instance and delete the cart container. C<filter> will be ignored.
+
+When called as a package method, this will delete all carts matching C<filter>.
+A Handel::Exception::Argument exception will be thrown is C<filter> is not a
+HASH reference.
+
+=back
+
 =head2 Saving Your Cart
 
 By default every shopping cart created is considered temporary
@@ -543,7 +584,7 @@ shopper at any time.
 
 =head1 SEE ALSO
 
-L<Handel::Contstants>
+L<Handel::Constants>
 
 =head1 AUTHOR
 
